@@ -13,8 +13,9 @@
 #'  custom persister.
 #' @param match_requests_on List of request matchers
 #' to use to determine what recorded HTTP interaction to replay. Defaults to
-#' `["method", "uri"]`. The built-in matchers are "method", "uri", "host",
-#' "path", "headers" and "body"
+#' `["method", "uri"]`. The built-in matchers are "method", "uri",
+#' "headers" and "body" ("host" and "path" not supported yet, but should 
+#' be in a future version)
 #' @param update_content_length_header (logical) Whether or
 #' not to overwrite the `Content-Length` header of the responses to
 #' match the length of the response body. Default: `FALSE`
@@ -159,9 +160,9 @@ Cassette <- R6::R6Class(
                ") is not in the allowed set: ",
                paste0(mro, collapse = ", "), call. = FALSE)
         }
-        # we don't yet support the following matchers: host, path, body
-        if (any(match_requests_on %in% c("host", "path", "body"))) {
-          stop("we do not yet support host, path, or body matchers",
+        # we don't yet support the following matchers: host, path
+        if (any(match_requests_on %in% c("host", "path"))) {
+          stop("we do not yet support host and path matchers",
             "\n see https://github.com/ropensci/vcr/issues/70",
             call. = FALSE)
         }
@@ -197,6 +198,9 @@ Cassette <- R6::R6Class(
       self$serializer = serializer_fetch(self$serialize_with, self$name)
       self$persister = persister_fetch(self$persist_with, self$serializer$path)
 
+      # check for re-record
+      if (self$should_re_record()) self$record <- "all"
+
       # get previously recorded interactions
       ## if none pass, if some found, make webmockr stubs
       #### first, get previously recorded interactions into `http_interactions_` var
@@ -209,23 +213,70 @@ Cassette <- R6::R6Class(
           res <- z$response
           uripp <- crul::url_parse(req$uri)
           m <- self$match_requests_on
-          if (all(m %in% c("method", "uri")) && length(m) == 2) {
+          if (length(m) == 1) {
+            if (m == "method") webmockr::stub_request(req$method, uri_regex = ".")
+            if (m == "uri") webmockr::stub_request("any", req$uri)
+            if (m == "query") {
+              tmp <- webmockr::stub_request("any", uri_regex = ".")
+              webmockr::wi_th(tmp, .list = list(query = uripp$parameter))
+            }
+            if (m == "headers") {
+              tmp <- webmockr::stub_request("any", uri_regex = ".")
+              webmockr::wi_th(tmp, .list = list(headers = req$headers))
+            }
+            if (m == "body") {
+              tmp <- webmockr::stub_request("any", uri_regex = ".+")
+              webmockr::wi_th(tmp, .list = list(body = req$body))
+            }
+          } else if (all(m %in% c("method", "uri")) && length(m) == 2) {
             webmockr::stub_request(req$method, req$uri)
           } else if (
-            all(m %in% c("method", "uri", "query")) && length(m) == 3) {
+            all(m %in% c("method", "body")) && length(m) == 2
+          ) {
+            tmp <- webmockr::stub_request(req$method, uri_regex = ".")
+            webmockr::wi_th(tmp, .list = list(body = req$body))
+          } else if (
+            all(m %in% c("method", "uri", "query")) && length(m) == 3
+          ) {
             tmp <- webmockr::stub_request(req$method, req$uri)
             webmockr::wi_th(tmp, .list = list(query = uripp$parameter))
           } else if (
-            all(m %in% c("method", "uri", "headers")) && length(m) == 3) {
+            all(m %in% c("method", "uri", "headers")) && length(m) == 3
+          ) {
             tmp <- webmockr::stub_request(req$method, req$uri)
-            webmockr::wi_th(tmp, .list = list(query = req$headers))
+            webmockr::wi_th(tmp, .list = list(headers = req$headers))
+          } else if (
+            all(m %in% c("method", "uri", "body")) && length(m) == 3
+          ) {
+            tmp <- webmockr::stub_request(req$method, req$uri)
+            webmockr::wi_th(tmp, .list = list(body = req$body))
           } else if (
             all(m %in% c("method", "uri", "headers", "query")) &&
-            length(m) == 4) {
+            length(m) == 4
+          ) {
             tmp <- webmockr::stub_request(req$method, req$uri)
             webmockr::wi_th(tmp, .list = list(query = uripp$parameter,
               headers = req$headers))
+          } else if (
+            all(m %in% c("method", "uri", "headers", "body")) &&
+            length(m) == 4
+          ) {
+            tmp <- webmockr::stub_request(req$method, req$uri)
+            webmockr::wi_th(tmp, .list = list(body = req$body,
+              headers = req$headers))
+          } else if (
+            all(m %in% c("method", "uri", "query", "body")) &&
+            length(m) == 4
+          ) {
+            tmp <- webmockr::stub_request(req$method, req$uri)
+            webmockr::wi_th(tmp, .list = list(query = uripp$parameter, 
+              body = req$body))
+          } else {
+            tmp <- webmockr::stub_request(req$method, req$uri)
+            webmockr::wi_th(tmp, .list = list(query = uripp$parameter, 
+              body = req$body, headers = req$headers))
           }
+          
         }))
       }
 
@@ -261,6 +312,10 @@ Cassette <- R6::R6Class(
       cat(paste0("  Record method: ", self$record), sep = "\n")
       cat(paste0("  Serialize with: ", self$serialize_with), sep = "\n")
       cat(paste0("  Persist with: ", self$persist_with), sep = "\n")
+      cat(paste0("  Re-record interval (s): ", self$re_record_interval),
+        sep = "\n")
+      cat(paste0("  Clean outdated interactions?: ",
+        self$clean_outdated_http_interactions), sep = "\n")
       cat(paste0("  update_content_length_header: ",
                  self$update_content_length_header), sep = "\n")
       cat(paste0("  decode_compressed_response: ",
@@ -318,12 +373,11 @@ Cassette <- R6::R6Class(
     },
 
     is_empty = function() {
-      # self$persister$is_empty()
       nchar(self$raw_cassette_bytes()) < 1
     },
 
     originally_recorded_at = function() {
-      self$recorded_at
+      as.POSIXct(self$recorded_at, tz = "GMT")
     },
 
     serializable_hash = function() {
@@ -369,23 +423,46 @@ Cassette <- R6::R6Class(
           )
       }
 
-      # FIXME: add up_to_date_interactions usage here
-      return(c(old_interactions, self$new_recorded_interactions))
+      return(c(self$up_to_date_interactions(old_interactions), 
+        self$new_recorded_interactions))
     },
 
-    # FIXME: not used yet, from newer version of vcr
     up_to_date_interactions = function(interactions) {
       if (
-        self$clean_outdated_http_interactions &&
-        !is.null(re_record_interval)
+        !self$clean_outdated_http_interactions && is.null(self$re_record_interval)
       ) {
         return(interactions)
       }
       Filter(function(z) {
-        as.POSIXct(z$recorded_at) > (Sys.time() - vcr_c$re_record_interval)
+        as.POSIXct(z$recorded_at, tz = "GMT") > (as.POSIXct(Sys.time(), tz = "GMT") - self$re_record_interval)
       }, interactions)
     },
 
+    should_re_record = function() {
+      if (is.null(self$re_record_interval)) return(FALSE)
+      if (is.null(self$originally_recorded_at())) return(FALSE)
+      now <- as.POSIXct(Sys.time(), tz = "GMT")
+      time_comp <- (self$originally_recorded_at() + self$re_record_interval) < now
+      info <- sprintf(
+        "previously recorded at: '%s'; now: '%s'; interval: %s seconds",
+        self$originally_recorded_at(), now, self$re_record_interval)
+
+      if (!time_comp) {
+        vcr_log_info(
+          sprintf("Not re-recording since the interval has not elapsed (%s).", info),
+          vcr_c$log_opts$date)
+        return(FALSE)
+      } else if (has_internet()) {
+        vcr_log_info(sprintf("re-recording (%s).", info), vcr_c$log_opts$date)
+        return(TRUE)
+      } else {
+        vcr_log_info(
+          sprintf("Not re-recording because no internet connection is available (%s).", info),
+          vcr_c$log_opts$date)
+        return(FALSE)
+      }
+    },
+
     should_stub_requests = function() {
       self$record != "all"
     },
@@ -502,7 +579,8 @@ Cassette <- R6::R6Class(
             list()
           }
         },
-        request_matchers = vcr_configuration()$match_requests_on
+        request_matchers = self$match_requests_on
+        # request_matchers = vcr_configuration()$match_requests_on
       )
     },
 
@@ -511,7 +589,8 @@ Cassette <- R6::R6Class(
         x$request$method,
         x$url,
         if (inherits(x, "response")) {
-          bd <- x$request$options$postfields
+          # bd <- x$request$options$postfields
+          bd <- get_httr_body(x$request)
           if (inherits(bd, "raw")) rawToChar(bd) else bd
         } else {
           x$request$fields
