@@ -7,11 +7,30 @@
 #'  record = "once"
 #' )
 #'
+#' # GET request
 #' library(httr)
 #' load("~/httr_req.rda")
 #' req
 #' x <- RequestHandlerHttr$new(req)
 #' # x$handle()
+#' 
+#' # POST request
+#' library(httr)
+#' webmockr::httr_mock()
+#' mydir <- file.path(tempdir(), "testing_httr")
+#' invisible(vcr_configure(dir = mydir))
+#' use_cassette(name = "testing2", {
+#'   res <- POST("https://httpbin.org/post", body = list(foo = "bar"))
+#' }, match_requests_on = c("method", "uri", "body"))
+#' 
+#' load("~/httr_req_post.rda")
+#' insert_cassette("testing3")
+#' httr_req_post
+#' x <- RequestHandlerHttr$new(httr_req_post)
+#' x
+#' # x$handle()
+#' self=x
+#' 
 #' }
 RequestHandlerHttr <- R6::R6Class(
   "RequestHandlerHttr",
@@ -22,7 +41,7 @@ RequestHandlerHttr <- R6::R6Class(
       self$request_original <- request
       self$request <- {
         Request$new(request$method, request$url,
-          request$body, request$headers)
+          pluck_body(request), request$headers)
       }
       self$cassette <- tryCatch(current_cassette(), error = function(e) e)
     }
@@ -71,7 +90,10 @@ RequestHandlerHttr <- R6::R6Class(
       webmockr::httr_mock(FALSE)
       on.exit(webmockr::httr_mock(TRUE), add = TRUE)
       tmp2 <- eval(parse(text = paste0("httr::",
-        self$request_original$method)))(self$request_original$url)
+        self$request_original$method)))(
+        self$request_original$url,
+        body = get_httr_body(self$request_original)
+      )
       response <- webmockr::build_httr_response(self$request_original, tmp2)
 
       # make vcr response | then record interaction
@@ -85,3 +107,19 @@ RequestHandlerHttr <- R6::R6Class(
     }
   )
 )
+
+get_httr_body <- function(x) {
+  if (is.null(x$fields) && is.null(x$options$postfields)) return(NULL)
+  if (!is.null(x$fields)) {
+    form_file_comp <- vapply(x$fields, inherits, logical(1), "form_file")
+    if (any(form_file_comp)) {
+      ff <- x$fields[form_file_comp][[1]]
+      return(ff)
+    } else {
+      return(x$fields)
+    }
+  }
+  if (!is.null(x$options$postfields)) {
+    if (is.raw(x$options$postfields)) return(rawToChar(x$options$postfields))
+  }
+}
