@@ -19,7 +19,8 @@ serialize_to_httr <- function(request, response) {
   resp$set_body(if ("string" %in% names(bod)) bod$string else bod)
   resp$set_request_headers(request$headers, capitalize = FALSE)
   resp$set_response_headers(response$headers, capitalize = FALSE)
-  resp$set_status(status = response$status %||% 200)
+  # resp$set_status(status = response$status %||% 200)
+  resp$set_status(status = response$status$status_code %||% 200)
 
   # generate httr response
   webmockr::build_httr_response(req, resp)
